@@ -11,55 +11,50 @@
 
 namespace Symfony\Bridge\Doctrine\Tests\Form\Type;
 
+use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\Common\Persistence\ManagerRegistry;
+use Doctrine\ORM\EntityManager;
+use Doctrine\ORM\EntityRepository;
+use Doctrine\ORM\Tools\SchemaTool;
+use Symfony\Bridge\Doctrine\Form\DoctrineOrmExtension;
+use Symfony\Bridge\Doctrine\Form\DoctrineOrmTypeGuesser;
+use Symfony\Bridge\Doctrine\Form\Type\EntityType;
 use Symfony\Bridge\Doctrine\Test\DoctrineTestHelper;
-use Symfony\Component\Form\Exception\UnexpectedTypeException;
-use Symfony\Component\Form\Test\TypeTestCase;
+use Symfony\Bridge\Doctrine\Tests\Fixtures\CompositeIntIdEntity;
+use Symfony\Bridge\Doctrine\Tests\Fixtures\CompositeStringIdEntity;
 use Symfony\Bridge\Doctrine\Tests\Fixtures\GroupableEntity;
 use Symfony\Bridge\Doctrine\Tests\Fixtures\SingleIntIdEntity;
 use Symfony\Bridge\Doctrine\Tests\Fixtures\SingleStringIdEntity;
-use Symfony\Bridge\Doctrine\Tests\Fixtures\CompositeIntIdEntity;
-use Symfony\Bridge\Doctrine\Tests\Fixtures\CompositeStringIdEntity;
-use Symfony\Bridge\Doctrine\Form\DoctrineOrmExtension;
-use Doctrine\ORM\Tools\SchemaTool;
-use Doctrine\Common\Collections\ArrayCollection;
-use Symfony\Component\Form\Extension\Core\View\ChoiceView;
+use Symfony\Component\Form\ChoiceList\View\ChoiceGroupView;
+use Symfony\Component\Form\ChoiceList\View\ChoiceView;
+use Symfony\Component\Form\Forms;
+use Symfony\Component\Form\Test\TypeTestCase;
+use Symfony\Component\PropertyAccess\PropertyAccess;
+use Symfony\Bridge\Doctrine\Tests\Fixtures\SingleAssociationToIntIdEntity;
+use Symfony\Bridge\Doctrine\Tests\Fixtures\SingleIntIdNoToStringEntity;
 
 class EntityTypeTest extends TypeTestCase
 {
     const ITEM_GROUP_CLASS = 'Symfony\Bridge\Doctrine\Tests\Fixtures\GroupableEntity';
     const SINGLE_IDENT_CLASS = 'Symfony\Bridge\Doctrine\Tests\Fixtures\SingleIntIdEntity';
+    const SINGLE_IDENT_NO_TO_STRING_CLASS = 'Symfony\Bridge\Doctrine\Tests\Fixtures\SingleIntIdNoToStringEntity';
     const SINGLE_STRING_IDENT_CLASS = 'Symfony\Bridge\Doctrine\Tests\Fixtures\SingleStringIdEntity';
+    const SINGLE_ASSOC_IDENT_CLASS = 'Symfony\Bridge\Doctrine\Tests\Fixtures\SingleAssociationToIntIdEntity';
     const COMPOSITE_IDENT_CLASS = 'Symfony\Bridge\Doctrine\Tests\Fixtures\CompositeIntIdEntity';
     const COMPOSITE_STRING_IDENT_CLASS = 'Symfony\Bridge\Doctrine\Tests\Fixtures\CompositeStringIdEntity';
 
     /**
-     * @var \Doctrine\ORM\EntityManager
+     * @var EntityManager
      */
     private $em;
 
     /**
-     * @var \PHPUnit_Framework_MockObject_MockObject
+     * @var \PHPUnit_Framework_MockObject_MockObject|ManagerRegistry
      */
     private $emRegistry;
 
     protected function setUp()
     {
-        if (!class_exists('Symfony\Component\Form\Form')) {
-            $this->markTestSkipped('The "Form" component is not available');
-        }
-
-        if (!class_exists('Doctrine\DBAL\Platforms\MySqlPlatform')) {
-            $this->markTestSkipped('Doctrine DBAL is not available.');
-        }
-
-        if (!class_exists('Doctrine\Common\Version')) {
-            $this->markTestSkipped('Doctrine Common is not available.');
-        }
-
-        if (!class_exists('Doctrine\ORM\EntityManager')) {
-            $this->markTestSkipped('Doctrine ORM is not available.');
-        }
-
         $this->em = DoctrineTestHelper::createTestEntityManager();
         $this->emRegistry = $this->createRegistryMock('default', $this->em);
 
@@ -69,7 +64,9 @@ class EntityTypeTest extends TypeTestCase
         $classes = array(
             $this->em->getClassMetadata(self::ITEM_GROUP_CLASS),
             $this->em->getClassMetadata(self::SINGLE_IDENT_CLASS),
+            $this->em->getClassMetadata(self::SINGLE_IDENT_NO_TO_STRING_CLASS),
             $this->em->getClassMetadata(self::SINGLE_STRING_IDENT_CLASS),
+            $this->em->getClassMetadata(self::SINGLE_ASSOC_IDENT_CLASS),
             $this->em->getClassMetadata(self::COMPOSITE_IDENT_CLASS),
             $this->em->getClassMetadata(self::COMPOSITE_STRING_IDENT_CLASS),
         );
@@ -119,6 +116,16 @@ class EntityTypeTest extends TypeTestCase
         $this->factory->createNamed('name', 'entity');
     }
 
+    /**
+     * @expectedException \Symfony\Component\Form\Exception\RuntimeException
+     */
+    public function testInvalidClassOption()
+    {
+        $this->factory->createNamed('name', 'entity', null, array(
+            'class' => 'foo',
+        ));
+    }
+
     public function testSetDataToUninitializedEntityWithNonRequired()
     {
         $entity1 = new SingleIntIdEntity(1, 'Foo');
@@ -130,7 +137,7 @@ class EntityTypeTest extends TypeTestCase
             'em' => 'default',
             'class' => self::SINGLE_IDENT_CLASS,
             'required' => false,
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         $this->assertEquals(array(1 => new ChoiceView($entity1, '1', 'Foo'), 2 => new ChoiceView($entity2, '2', 'Bar')), $field->createView()->vars['choices']);
@@ -164,7 +171,7 @@ class EntityTypeTest extends TypeTestCase
             'em' => 'default',
             'class' => self::SINGLE_IDENT_CLASS,
             'required' => false,
-            'property' => 'name',
+            'choice_label' => 'name',
             'query_builder' => $qb,
         ));
 
@@ -172,7 +179,7 @@ class EntityTypeTest extends TypeTestCase
     }
 
     /**
-     * @expectedException \Symfony\Component\Form\Exception\UnexpectedTypeException
+     * @expectedException \Symfony\Component\OptionsResolver\Exception\InvalidOptionsException
      */
     public function testConfigureQueryBuilderWithNonQueryBuilderAndNonClosure()
     {
@@ -251,7 +258,7 @@ class EntityTypeTest extends TypeTestCase
         $field->submit(null);
 
         $this->assertNull($field->getData());
-        $this->assertSame(array(), $field->getViewData());
+        $this->assertNull($field->getViewData());
     }
 
     public function testSubmitSingleNonExpandedNull()
@@ -293,7 +300,32 @@ class EntityTypeTest extends TypeTestCase
             'expanded' => false,
             'em' => 'default',
             'class' => self::SINGLE_IDENT_CLASS,
-            'property' => 'name',
+            'choice_label' => 'name',
+        ));
+
+        $field->submit('2');
+
+        $this->assertTrue($field->isSynchronized());
+        $this->assertSame($entity2, $field->getData());
+        $this->assertSame('2', $field->getViewData());
+    }
+
+    public function testSubmitSingleNonExpandedSingleAssocIdentifier()
+    {
+        $innerEntity1 = new SingleIntIdNoToStringEntity(1, 'InFoo');
+        $innerEntity2 = new SingleIntIdNoToStringEntity(2, 'InBar');
+
+        $entity1 = new SingleAssociationToIntIdEntity($innerEntity1, 'Foo');
+        $entity2 = new SingleAssociationToIntIdEntity($innerEntity2, 'Bar');
+
+        $this->persist(array($innerEntity1, $innerEntity2, $entity1, $entity2));
+
+        $field = $this->factory->createNamed('name', 'entity', null, array(
+            'multiple' => false,
+            'expanded' => false,
+            'em' => 'default',
+            'class' => self::SINGLE_ASSOC_IDENT_CLASS,
+            'choice_label' => 'name',
         ));
 
         $field->submit('2');
@@ -315,7 +347,7 @@ class EntityTypeTest extends TypeTestCase
             'expanded' => false,
             'em' => 'default',
             'class' => self::COMPOSITE_IDENT_CLASS,
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         // the collection key is used here
@@ -339,7 +371,36 @@ class EntityTypeTest extends TypeTestCase
             'expanded' => false,
             'em' => 'default',
             'class' => self::SINGLE_IDENT_CLASS,
-            'property' => 'name',
+            'choice_label' => 'name',
+        ));
+
+        $field->submit(array('1', '3'));
+
+        $expected = new ArrayCollection(array($entity1, $entity3));
+
+        $this->assertTrue($field->isSynchronized());
+        $this->assertEquals($expected, $field->getData());
+        $this->assertSame(array('1', '3'), $field->getViewData());
+    }
+
+    public function testSubmitMultipleNonExpandedSingleAssocIdentifier()
+    {
+        $innerEntity1 = new SingleIntIdNoToStringEntity(1, 'InFoo');
+        $innerEntity2 = new SingleIntIdNoToStringEntity(2, 'InBar');
+        $innerEntity3 = new SingleIntIdNoToStringEntity(3, 'InBaz');
+
+        $entity1 = new SingleAssociationToIntIdEntity($innerEntity1, 'Foo');
+        $entity2 = new SingleAssociationToIntIdEntity($innerEntity2, 'Bar');
+        $entity3 = new SingleAssociationToIntIdEntity($innerEntity3, 'Baz');
+
+        $this->persist(array($innerEntity1, $innerEntity2, $innerEntity3, $entity1, $entity2, $entity3));
+
+        $field = $this->factory->createNamed('name', 'entity', null, array(
+            'multiple' => true,
+            'expanded' => false,
+            'em' => 'default',
+            'class' => self::SINGLE_ASSOC_IDENT_CLASS,
+            'choice_label' => 'name',
         ));
 
         $field->submit(array('1', '3'));
@@ -364,7 +425,7 @@ class EntityTypeTest extends TypeTestCase
             'expanded' => false,
             'em' => 'default',
             'class' => self::SINGLE_IDENT_CLASS,
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         $existing = new ArrayCollection(array(0 => $entity2));
@@ -395,7 +456,7 @@ class EntityTypeTest extends TypeTestCase
             'expanded' => false,
             'em' => 'default',
             'class' => self::COMPOSITE_IDENT_CLASS,
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         // because of the composite key collection keys are used
@@ -421,7 +482,7 @@ class EntityTypeTest extends TypeTestCase
             'expanded' => false,
             'em' => 'default',
             'class' => self::COMPOSITE_IDENT_CLASS,
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         $existing = new ArrayCollection(array(0 => $entity2));
@@ -451,7 +512,7 @@ class EntityTypeTest extends TypeTestCase
             'expanded' => true,
             'em' => 'default',
             'class' => self::SINGLE_IDENT_CLASS,
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         $field->submit('2');
@@ -477,7 +538,7 @@ class EntityTypeTest extends TypeTestCase
             'expanded' => true,
             'em' => 'default',
             'class' => self::SINGLE_IDENT_CLASS,
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         $field->submit(array('1', '3'));
@@ -494,6 +555,31 @@ class EntityTypeTest extends TypeTestCase
         $this->assertSame('3', $field['3']->getViewData());
     }
 
+    public function testSubmitMultipleExpandedWithNegativeIntegerId()
+    {
+        $entity1 = new SingleIntIdEntity(-1, 'Foo');
+        $entity2 = new SingleIntIdEntity(2, 'Bar');
+
+        $this->persist(array($entity1, $entity2));
+
+        $field = $this->factory->createNamed('name', 'entity', null, array(
+            'multiple' => true,
+            'expanded' => true,
+            'em' => 'default',
+            'class' => self::SINGLE_IDENT_CLASS,
+            'choice_label' => 'name',
+        ));
+
+        $field->submit(array('-1'));
+
+        $expected = new ArrayCollection(array($entity1));
+
+        $this->assertTrue($field->isSynchronized());
+        $this->assertEquals($expected, $field->getData());
+        $this->assertTrue($field['_1']->getData());
+        $this->assertFalse($field['2']->getData());
+    }
+
     public function testOverrideChoices()
     {
         $entity1 = new SingleIntIdEntity(1, 'Foo');
@@ -507,7 +593,7 @@ class EntityTypeTest extends TypeTestCase
             'class' => self::SINGLE_IDENT_CLASS,
             // not all persisted entities should be displayed
             'choices' => array($entity1, $entity2),
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         $field->submit('2');
@@ -531,7 +617,7 @@ class EntityTypeTest extends TypeTestCase
             'em' => 'default',
             'class' => self::ITEM_GROUP_CLASS,
             'choices' => array($item1, $item2, $item3, $item4),
-            'property' => 'name',
+            'choice_label' => 'name',
             'group_by' => 'groupName',
         ));
 
@@ -539,9 +625,14 @@ class EntityTypeTest extends TypeTestCase
 
         $this->assertSame('2', $field->getViewData());
         $this->assertEquals(array(
-            'Group1' => array(1 => new ChoiceView($item1, '1', 'Foo'), 2 => new ChoiceView($item2, '2', 'Bar')),
-            'Group2' => array(3 => new ChoiceView($item3, '3', 'Baz')),
-            '4' => new ChoiceView($item4, '4', 'Boo!'),
+            'Group1' => new ChoiceGroupView('Group1', array(
+                1 => new ChoiceView($item1, '1', 'Foo'),
+                2 => new ChoiceView($item2, '2', 'Bar'),
+            )),
+            'Group2' => new ChoiceGroupView('Group2', array(
+                3 => new ChoiceView($item3, '3', 'Baz'),
+            )),
+            4 => new ChoiceView($item4, '4', 'Boo!'),
         ), $field->createView()->vars['choices']);
     }
 
@@ -557,7 +648,7 @@ class EntityTypeTest extends TypeTestCase
             'em' => 'default',
             'class' => self::SINGLE_IDENT_CLASS,
             'preferred_choices' => array($entity3, $entity2),
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         $this->assertEquals(array(3 => new ChoiceView($entity3, '3', 'Baz'), 2 => new ChoiceView($entity2, '2', 'Bar')), $field->createView()->vars['preferred_choices']);
@@ -577,7 +668,7 @@ class EntityTypeTest extends TypeTestCase
             'class' => self::SINGLE_IDENT_CLASS,
             'choices' => array($entity2, $entity3),
             'preferred_choices' => array($entity3),
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         $this->assertEquals(array(3 => new ChoiceView($entity3, '3', 'Baz')), $field->createView()->vars['preferred_choices']);
@@ -596,7 +687,30 @@ class EntityTypeTest extends TypeTestCase
             'em' => 'default',
             'class' => self::SINGLE_IDENT_CLASS,
             'choices' => array($entity1, $entity2),
-            'property' => 'name',
+            'choice_label' => 'name',
+        ));
+
+        $field->submit('3');
+
+        $this->assertFalse($field->isSynchronized());
+        $this->assertNull($field->getData());
+    }
+
+    public function testDisallowChoicesThatAreNotIncludedChoicesSingleAssocIdentifier()
+    {
+        $innerEntity1 = new SingleIntIdNoToStringEntity(1, 'InFoo');
+        $innerEntity2 = new SingleIntIdNoToStringEntity(2, 'InBar');
+
+        $entity1 = new SingleAssociationToIntIdEntity($innerEntity1, 'Foo');
+        $entity2 = new SingleAssociationToIntIdEntity($innerEntity2, 'Bar');
+
+        $this->persist(array($innerEntity1, $innerEntity2, $entity1, $entity2));
+
+        $field = $this->factory->createNamed('name', 'entity', null, array(
+            'em' => 'default',
+            'class' => self::SINGLE_ASSOC_IDENT_CLASS,
+            'choices' => array($entity1, $entity2),
+            'choice_label' => 'name',
         ));
 
         $field->submit('3');
@@ -617,7 +731,7 @@ class EntityTypeTest extends TypeTestCase
             'em' => 'default',
             'class' => self::COMPOSITE_IDENT_CLASS,
             'choices' => array($entity1, $entity2),
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         $field->submit('2');
@@ -641,7 +755,35 @@ class EntityTypeTest extends TypeTestCase
             'class' => self::SINGLE_IDENT_CLASS,
             'query_builder' => $repository->createQueryBuilder('e')
                 ->where('e.id IN (1, 2)'),
-            'property' => 'name',
+            'choice_label' => 'name',
+        ));
+
+        $field->submit('3');
+
+        $this->assertFalse($field->isSynchronized());
+        $this->assertNull($field->getData());
+    }
+
+    public function testDisallowChoicesThatAreNotIncludedQueryBuilderSingleAssocIdentifier()
+    {
+        $innerEntity1 = new SingleIntIdNoToStringEntity(1, 'InFoo');
+        $innerEntity2 = new SingleIntIdNoToStringEntity(2, 'InBar');
+        $innerEntity3 = new SingleIntIdNoToStringEntity(3, 'InBaz');
+
+        $entity1 = new SingleAssociationToIntIdEntity($innerEntity1, 'Foo');
+        $entity2 = new SingleAssociationToIntIdEntity($innerEntity2, 'Bar');
+        $entity3 = new SingleAssociationToIntIdEntity($innerEntity3, 'Baz');
+
+        $this->persist(array($innerEntity1, $innerEntity2, $innerEntity3, $entity1, $entity2, $entity3));
+
+        $repository = $this->em->getRepository(self::SINGLE_ASSOC_IDENT_CLASS);
+
+        $field = $this->factory->createNamed('name', 'entity', null, array(
+            'em' => 'default',
+            'class' => self::SINGLE_ASSOC_IDENT_CLASS,
+            'query_builder' => $repository->createQueryBuilder('e')
+                ->where('e.entity IN (1, 2)'),
+            'choice_label' => 'name',
         ));
 
         $field->submit('3');
@@ -663,9 +805,9 @@ class EntityTypeTest extends TypeTestCase
             'class' => self::SINGLE_IDENT_CLASS,
             'query_builder' => function ($repository) {
                 return $repository->createQueryBuilder('e')
-                        ->where('e.id IN (1, 2)');
+                    ->where('e.id IN (1, 2)');
             },
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         $field->submit('3');
@@ -687,9 +829,9 @@ class EntityTypeTest extends TypeTestCase
             'class' => self::COMPOSITE_IDENT_CLASS,
             'query_builder' => function ($repository) {
                 return $repository->createQueryBuilder('e')
-                        ->where('e.id1 IN (10, 50)');
+                    ->where('e.id1 IN (10, 50)');
             },
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         $field->submit('2');
@@ -709,7 +851,7 @@ class EntityTypeTest extends TypeTestCase
             'expanded' => false,
             'em' => 'default',
             'class' => self::SINGLE_STRING_IDENT_CLASS,
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         $field->submit('foo');
@@ -730,7 +872,7 @@ class EntityTypeTest extends TypeTestCase
             'expanded' => false,
             'em' => 'default',
             'class' => self::COMPOSITE_STRING_IDENT_CLASS,
-            'property' => 'name',
+            'choice_label' => 'name',
         ));
 
         // the collection key is used here
@@ -752,19 +894,141 @@ class EntityTypeTest extends TypeTestCase
             ->will($this->returnValue($this->em));
 
         $this->factory->createNamed('name', 'entity', null, array(
+            'class' => self::SINGLE_IDENT_CLASS,
+            'required' => false,
+            'choice_label' => 'name',
+        ));
+    }
+
+    public function testExplicitEm()
+    {
+        $this->emRegistry->expects($this->never())
+            ->method('getManager');
+
+        $this->emRegistry->expects($this->never())
+            ->method('getManagerForClass');
+
+        $this->factory->createNamed('name', 'entity', null, array(
+            'em' => $this->em,
+            'class' => self::SINGLE_IDENT_CLASS,
+            'choice_label' => 'name',
+        ));
+    }
+
+    public function testLoaderCaching()
+    {
+        $entity1 = new SingleIntIdEntity(1, 'Foo');
+        $entity2 = new SingleIntIdEntity(2, 'Bar');
+        $entity3 = new SingleIntIdEntity(3, 'Baz');
+
+        $this->persist(array($entity1, $entity2, $entity3));
+
+        $repo = $this->em->getRepository(self::SINGLE_IDENT_CLASS);
+
+        $entityType = new EntityType(
+            $this->emRegistry,
+            PropertyAccess::createPropertyAccessor()
+        );
+
+        $entityTypeGuesser = new DoctrineOrmTypeGuesser($this->emRegistry);
+
+        $factory = Forms::createFormFactoryBuilder()
+            ->addType($entityType)
+            ->addTypeGuesser($entityTypeGuesser)
+            ->getFormFactory();
+
+        $formBuilder = $factory->createNamedBuilder('form', 'form');
+
+        $formBuilder->add('property1', 'entity', array(
+            'em' => 'default',
+            'class' => self::SINGLE_IDENT_CLASS,
+            'query_builder' => $repo->createQueryBuilder('e')->where('e.id IN (1, 2)'),
+        ));
+
+        $formBuilder->add('property2', 'entity', array(
+            'em' => 'default',
+            'class' => self::SINGLE_IDENT_CLASS,
+            'query_builder' => function (EntityRepository $repo) {
+                return $repo->createQueryBuilder('e')->where('e.id IN (1, 2)');
+            },
+        ));
+
+        $formBuilder->add('property3', 'entity', array(
+            'em' => 'default',
+            'class' => self::SINGLE_IDENT_CLASS,
+            'query_builder' => function (EntityRepository $repo) {
+                return $repo->createQueryBuilder('e')->where('e.id IN (1, 2)');
+            },
+        ));
+
+        $form = $formBuilder->getForm();
+
+        $form->submit(array(
+            'property1' => 1,
+            'property2' => 1,
+            'property3' => 2,
+        ));
+
+        $choiceList1 = $form->get('property1')->getConfig()->getOption('choice_list');
+        $choiceList2 = $form->get('property2')->getConfig()->getOption('choice_list');
+        $choiceList3 = $form->get('property3')->getConfig()->getOption('choice_list');
+
+        $this->assertInstanceOf('Symfony\Component\Form\ChoiceList\ChoiceListInterface', $choiceList1);
+        $this->assertSame($choiceList1, $choiceList2);
+        $this->assertSame($choiceList1, $choiceList3);
+    }
+
+    public function testCacheChoiceLists()
+    {
+        $entity1 = new SingleIntIdEntity(1, 'Foo');
+
+        $this->persist(array($entity1));
+
+        $field1 = $this->factory->createNamed('name', 'entity', null, array(
+            'em' => 'default',
+            'class' => self::SINGLE_IDENT_CLASS,
+            'required' => false,
+            'choice_label' => 'name',
+        ));
+
+        $field2 = $this->factory->createNamed('name', 'entity', null, array(
+            'em' => 'default',
+            'class' => self::SINGLE_IDENT_CLASS,
+            'required' => false,
+            'choice_label' => 'name',
+        ));
+
+        $this->assertInstanceOf('Symfony\Component\Form\ChoiceList\ChoiceListInterface', $field1->getConfig()->getOption('choice_list'));
+        $this->assertSame($field1->getConfig()->getOption('choice_list'), $field2->getConfig()->getOption('choice_list'));
+    }
+
+    /**
+     * @group legacy
+     */
+    public function testPropertyOption()
+    {
+        $entity1 = new SingleIntIdEntity(1, 'Foo');
+        $entity2 = new SingleIntIdEntity(2, 'Bar');
+
+        $this->persist(array($entity1, $entity2));
+
+        $field = $this->factory->createNamed('name', 'entity', null, array(
+            'em' => 'default',
             'class' => self::SINGLE_IDENT_CLASS,
             'required' => false,
             'property' => 'name',
         ));
+
+        $this->assertEquals(array(1 => new ChoiceView($entity1, '1', 'Foo'), 2 => new ChoiceView($entity2, '2', 'Bar')), $field->createView()->vars['choices']);
     }
 
     protected function createRegistryMock($name, $em)
     {
         $registry = $this->getMock('Doctrine\Common\Persistence\ManagerRegistry');
         $registry->expects($this->any())
-                 ->method('getManager')
-                 ->with($this->equalTo($name))
-                 ->will($this->returnValue($em));
+            ->method('getManager')
+            ->with($this->equalTo($name))
+            ->will($this->returnValue($em));
 
         return $registry;
     }
