@@ -13,6 +13,8 @@ namespace Symfony\Component\Stopwatch\Tests;
 
 use Symfony\Component\Stopwatch\Stopwatch;
 
+require_once __DIR__.'/ClockMock.php';
+
 /**
  * StopwatchTest.
  *
@@ -22,6 +24,16 @@ class StopwatchTest extends \PHPUnit_Framework_TestCase
 {
     const DELTA = 20;
 
+    protected function setUp()
+    {
+        with_clock_mock(true);
+    }
+
+    protected function tearDown()
+    {
+        with_clock_mock(false);
+    }
+
     public function testStart()
     {
         $stopwatch = new Stopwatch();
